From b283598a07dfdd4e54f01f514b1bf8ae891b3a1d Mon Sep 17 00:00:00 2001
From: Florian Schaal <florian@schaal-24.de>
Date: Thu, 21 Nov 2013 05:03:47 -0500
Subject: [PATCH] interface/web/dns/dns_wizard.php

---
 interface/web/designer/module_list.php |   57 ++++++++++++++++++++++++---------------------------------
 1 files changed, 24 insertions(+), 33 deletions(-)

diff --git a/interface/web/designer/module_list.php b/interface/web/designer/module_list.php
index 6449037..b08707e 100644
--- a/interface/web/designer/module_list.php
+++ b/interface/web/designer/module_list.php
@@ -27,52 +27,43 @@
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-require_once('../../lib/config.inc.php');
-require_once('../../lib/app.inc.php');
+require_once '../../lib/config.inc.php';
+require_once '../../lib/app.inc.php';
 
-// Checking permissions for the module
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
-	header("Location: ../index.php");
-	exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('designer');
 
 $app->uses('tpl');
 
-$app->tpl->newTemplate("form.tpl.htm");
-$app->tpl->setInclude('content_tpl','templates/module_list.htm');
+$app->tpl->newTemplate('form.tpl.htm');
+$app->tpl->setInclude('content_tpl', 'templates/module_list.htm');
 
-// lese Module aus
-$bgcolor = "#FFFFFF";
+//* Pick out modules
+$bgcolor = '#FFFFFF';
 $modules_list = array();
-$handle = @opendir($conf["rootpath"]."/web"); 
-while ($file = @readdir ($handle)) { 
-    if ($file != "." && $file != "..") {
-        if(@is_dir($conf["rootpath"]."/web/".$file)) {
-            if(is_file($conf["rootpath"]."/web/".$file."/lib/module.conf.php") and $file != 'login') {
-				include_once($conf["rootpath"]."/web/".$file."/lib/module.conf.php");
-				
-				// Farbwechsel
-				$bgcolor = ($bgcolor == "#FFFFFF")?"#EEEEEE":"#FFFFFF";
-				
-				$modules_list[] = array( 	'module' => $module["name"],
-											'title' => $module["title"],
-											'bgcolor' => $bgcolor);
+$handle = @opendir(ISPC_WEB_PATH);
+while ($file = @readdir($handle)) {
+	if ($file != '.' && $file != '..') {
+		if(@is_dir(ISPC_WEB_PATH."/$file")) {
+			if(is_file(ISPC_WEB_PATH."/$file/lib/module.conf.php") and $file != 'login') {
+				include_once ISPC_WEB_PATH."/$file/lib/module.conf.php";
+				$modules_list[] = array(  'module' =>   $module['name'],
+					'title' =>    $module['title'],
+					'bgcolor' =>  ($bgcolor == '#FFFFFF') ? '#EEEEEE' : '#FFFFFF'
+				);
 			}
-        }
+		}
 	}
 }
 
+$app->tpl->setLoop('records', $modules_list);
 
-$app->tpl->setLoop('records',$modules_list);
-
-// loading language file 
-$lng_file = "lib/lang/".$_SESSION["s"]["language"]."_module_list.lng";
-include($lng_file);
+//* loading language file
+$lng_file = 'lib/lang/'.$_SESSION['s']['language'].'_module_list.lng';
+include $lng_file;
 $app->tpl->setVar($wb);
 
 $app->tpl_defaults();
 $app->tpl->pparse();
 
-
-
-?>
\ No newline at end of file
+?>

--
Gitblit v1.9.1